Documentation
¶
Index ¶
Constants ¶
const EventTsLayout = "2006-01-02 15:04:05.000"
Variables ¶
This section is empty.
Functions ¶
func RuneToEventExpected ¶
func TeaKeyMsgToEventTyped ¶
Converts a bubbletea key message to a string. Used to properly record key events.
Types ¶
type Event ¶
type Event struct {
// The moment the event took place.
Ts time.Time
// The key that was Typed.
Typed string
// The rune that was Expected. Optional, since the user
// may have pressed backspace.
Expected string
// The index of the exercise when the rune was typed.
I int
}
A recording of a keypress during the exercise.
These are used to perform analysis on the user's performance, display stats, and keys that were causing the most trouble.
func ParseEvent ¶
Converts an event string to an event struct.
Click to show internal directories.
Click to hide internal directories.